package com.ruixuan.open.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.kuaishou.merchant.open.api.KsMerchantApiException;
import com.kuaishou.merchant.open.api.client.AccessTokenKsMerchantClient;
import com.kuaishou.merchant.open.api.common.utils.GsonUtils;
import com.kuaishou.merchant.open.api.request.video.OpenPhotoCountRequest;
import com.kuaishou.merchant.open.api.response.video.OpenPhotoCountResponse;
import com.ruixuan.isc.constants.KuaiShouConstants;
import com.ruixuan.isc.entity.JYAccessToken;
import com.ruixuan.isc.mapper.AccessTokenMapper;
import com.ruixuan.open.entity.KuaishouOpenPhotoCount;
import com.ruixuan.open.mapper.KuaishouOpenPhotoCountMapper;
import com.ruixuan.open.service.IKuaishouOpenPhotoCountService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 视频数量Service业务层处理
 *
 * @author ruoyi
 * @date 2024-07-09
 */
@Slf4j
@Service
public class KuaishouOpenPhotoCountServiceImpl implements IKuaishouOpenPhotoCountService {
    @Autowired
    private KuaishouOpenPhotoCountMapper kuaishouOpenPhotoCountMapper;

    @Autowired
    private AccessTokenMapper accessTokenMapper;

    /**
     * 查询视频数量
     *
     * @param id 视频数量主键
     * @return 视频数量
     */
    @Override
    public KuaishouOpenPhotoCount selectKuaishouOpenPhotoCountById(Long id) {
        return kuaishouOpenPhotoCountMapper.selectKuaishouOpenPhotoCountById(id);
    }

    /**
     * 查询视频数量列表
     *
     * @param kuaishouOpenPhotoCount 视频数量
     * @return 视频数量
     */
    @Override
    public List<KuaishouOpenPhotoCount> selectKuaishouOpenPhotoCountList(KuaishouOpenPhotoCount kuaishouOpenPhotoCount) {
        return kuaishouOpenPhotoCountMapper.selectKuaishouOpenPhotoCountList(kuaishouOpenPhotoCount);
    }


    @Override
    public void insertKuaishouOpenPhotoCount() {
        List<JYAccessToken> jyTokenInfos = accessTokenMapper.getJYTokenInfos();
        for (JYAccessToken tokenInfo : jyTokenInfos) {
            insertInfo(tokenInfo, null);
        }
    }

    private void insertInfo(JYAccessToken token, String cursor) {
        try {
            String appKey = token.getAppKey();
            String signSecret = token.getSignSecret();
            String accessToken = token.getAccessToken();
            AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, appKey, signSecret);

            OpenPhotoCountRequest request = new OpenPhotoCountRequest();
            request.setAccessToken(accessToken);
            //请求的API版本号，目前版本为1
            request.setApiMethodVersion(1L);

            OpenPhotoCountResponse response = client.execute(request);
            JSONObject resultJson = JSONObject.parseObject(GsonUtils.toJSON(response));
            String code = resultJson.getString("code");
            if ("1".equals(code)) {
                KuaishouOpenPhotoCount photoCount = JSONObject.parseObject(resultJson.getJSONObject("data").toJSONString(), KuaishouOpenPhotoCount.class);
                photoCount.setPromoterId(Long.valueOf(token.getPromoterId()));
                kuaishouOpenPhotoCountMapper.insertKuaishouOpenPhotoCount(photoCount);
            } else {
                log.error("===新增视频数量（open.photo.count）失败，promoterId:{}，信息：{}", token.getPromoterId(), resultJson.getString("msg"));
            }
        } catch (KsMerchantApiException e) {
            e.printStackTrace();
        }
    }

}
